import chalk from 'chalk';
export var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["debug"] = 0] = "debug";
    LogLevel[LogLevel["verbose"] = 1] = "verbose";
    LogLevel[LogLevel["info"] = 2] = "info";
    LogLevel[LogLevel["warn"] = 3] = "warn";
    LogLevel[LogLevel["error"] = 4] = "error";
})(LogLevel || (LogLevel = {}));
export const BasicLoggerStyler = {
    getColor: (level, _nesting = 0) => {
        switch (level) {
            case LogLevel.error:
                return chalk.red;
            case LogLevel.warn:
                return chalk.yellow;
            case LogLevel.debug:
            case LogLevel.verbose:
                return chalk.white.dim;
            default:
                return chalk.white;
        }
    },
    formatPrefix: (prefix, level, _nesting = 0) => level === LogLevel.debug || level === LogLevel.verbose
        ? chalk.dim(prefix)
        : '',
};
const loggerStyle = BasicLoggerStyler;
export class Logger {
    prefix;
    logLevel;
    logLevelIndex;
    parent;
    name;
    nesting;
    customPrefix;
    constructor({ name, parent = undefined, logLevel = parent?.logLevel ?? LogLevel.info, customPrefix, }) {
        this.customPrefix = customPrefix;
        this.name = name;
        this.parent = parent;
        this.logLevel = logLevel;
        this.logLevelIndex = logLevel;
        // Calculate indent level and offset based on parent chain
        this.nesting = 0;
        let offsetSpaces = 0;
        let currentParent = parent;
        while (currentParent) {
            offsetSpaces += 2;
            this.nesting++;
            currentParent = currentParent.parent;
        }
        this.prefix = ' '.repeat(offsetSpaces);
    }
    toStrings(messages) {
        return messages
            .map((message) => typeof message === 'object'
            ? JSON.stringify(message, null, 2)
            : String(message))
            .join(' ');
    }
    formatMessages(level, messages) {
        const formatted = this.toStrings(messages);
        const messageColor = loggerStyle.getColor(level, this.nesting);
        const prefix = loggerStyle.formatPrefix(`[${this.name}]`, level, this.nesting);
        let combinedPrefix = `${this.prefix}${prefix}`;
        if (this.customPrefix) {
            combinedPrefix = `${this.prefix}${this.customPrefix} `;
        }
        else if (combinedPrefix.length > 0) {
            combinedPrefix += ' ';
        }
        return formatted
            .split('\n')
            .map((line) => `${combinedPrefix}${messageColor(line)}`)
            .join('\n');
    }
    log(level, ...messages) {
        if (this.logLevelIndex > level)
            return;
        console.log(this.formatMessages(level, messages));
    }
    debug(...messages) {
        if (this.logLevelIndex > LogLevel.debug)
            return;
        console.log(this.formatMessages(LogLevel.debug, messages));
    }
    verbose(...messages) {
        if (this.logLevelIndex > LogLevel.verbose)
            return;
        console.log(this.formatMessages(LogLevel.verbose, messages));
    }
    info(...messages) {
        if (this.logLevelIndex > LogLevel.info)
            return;
        console.log(this.formatMessages(LogLevel.info, messages));
    }
    warn(...messages) {
        if (this.logLevelIndex > LogLevel.warn)
            return;
        console.warn(this.formatMessages(LogLevel.warn, messages));
    }
    error(...messages) {
        console.error(this.formatMessages(LogLevel.error, messages));
    }
}
//# sourceMappingURL=logger.js.map